==> scipion-em-continuousflex-3.0.7.tar.gz: scipion-em-continuousflex-3.0.7/continuousflex/viewers/__init__.py <==
# **************************************************************************
# *
# * Authors:     J.M. De la Rosa Trevin (jmdelarosa@cnb.csic.es)
# *              Slavica Jonic  (slavica.jonic@upmc.fr)
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************
from .viewer_nma import FlexNMAViewer
from .viewer_nma_alignment import FlexAlignmentNMAViewer
from .viewer_nma_dimred import FlexDimredNMAViewer
from .viewer_structure_mapping import FlexProtStructureMappingViewer
from .viewer_subtomograms_synthesize import FlexProtSynthesizeSubtomoViewer
from .viewer_pdb_dimred import FlexProtPdbDimredViewer
from .viewer_subtomograms_classify import FlexProtSubtomoClassifyViewer
from .viewer_nma_alignment_vol import FlexAlignmentNMAVolViewer
from .viewer_nma_dimred_vol import FlexDimredNMAVolViewer

==> scipion-em-continuousflex-3.4.0.tar.gz: scipion-em-continuousflex-3.4.0/continuousflex/viewers/__init__.py <==
# **************************************************************************
# *
# * Authors:     J.M. De la Rosa Trevin (jmdelarosa@cnb.csic.es)
# *              Slavica Jonic  (slavica.jonic@upmc.fr)
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************
from .viewer_nma import FlexNMAViewer
from .viewer_nma_alignment import FlexAlignmentNMAViewer
from .viewer_nma_dimred import FlexDimredNMAViewer
from .viewer_structure_mapping import FlexProtStructureMappingViewer
from .viewer_subtomograms_synthesize import FlexProtSynthesizeSubtomoViewer
from .viewer_pdb_dimred import FlexProtPdbDimredViewer, VolumeTrajectoryViewer
from .viewer_subtomograms_classify import FlexProtSubtomoClassifyViewer
from .viewer_nma_alignment_vol import FlexAlignmentNMAVolViewer
from .viewer_nma_dimred_vol import FlexDimredNMAVolViewer
from .viewer_image_synthesize import FlexProtSynthesizeImageViewer
from .viewer_heteroflow_dimred import FlexDimredHeteroFlowViewer
from .viewer_heteroflow import FlexHeteroFlowViewer
from .viewer_mdspace import FlexMDSPACEViewer
from .viewer_genesis import FlexGenesisViewer
from .viewer_deephemnma_train import FlexDeepHEMNMAViewer
from .viewer_deephemnma_infer import FlexDeepHEMNMAinferViewer
